[gjs/wip/ptomato/mozjs45prep: 13/16] jsapi-constructor-proxy: getPrototypeOf -> getPrototype



commit b2a07f0383af601a96c0cc067e1f075c8c8ed598
Author: Philip Chimento <philip endlessm com>
Date:   Sun Mar 19 05:17:24 2017 +0000

    jsapi-constructor-proxy: getPrototypeOf -> getPrototype

 gjs/jsapi-constructor-proxy.cpp |    8 ++++----
 1 files changed, 4 insertions(+), 4 deletions(-)
---
diff --git a/gjs/jsapi-constructor-proxy.cpp b/gjs/jsapi-constructor-proxy.cpp
index aede3c3..272f90e 100644
--- a/gjs/jsapi-constructor-proxy.cpp
+++ b/gjs/jsapi-constructor-proxy.cpp
@@ -43,7 +43,7 @@
  * getPrototypeOf() trap, which may or may not be turned on in JS proxies,
  * I'm not sure.
  *
  * COMPAT: SpiderMonkey doesn't support the getPrototypeOf() trap in JS
  * proxies yet. That has yet to be released, in the upcoming SpiderMonkey 52.
  * When that is available, then this whole file can be discontinued.
  *
@@ -87,9 +87,9 @@ public:
     { }
 
     bool
-    getPrototypeOf(JSContext              *cx,
-                   JS::HandleObject        proxy,
-                   JS::MutableHandleObject proto_p)
+    getPrototype(JSContext              *cx,
+                 JS::HandleObject        proxy,
+                 JS::MutableHandleObject proto_p)
     const override
     {
         proto_p.set(proto(proxy));
@@ -43,7 +43,7 @@
  * I'm not sure.
  *
- * COMPAT: SpiderMonkey doesn't support the getPrototypeOf() trap in JS
+ * COMPAT: SpiderMonkey doesn't support the getPrototype() trap in JS
  * proxies yet. That has yet to be released, in the upcoming SpiderMonkey 52.
  * When that is available, then this whole file can be discontinued.


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]